"""LangChain integration for LightningProx - Pay-per-use AI via Lightning Network."""

from langchain_lightningprox.llm import LightningProxLLM, LightningProx

__version__ = "0.1.0"
__all__ = ["LightningProxLLM", "LightningProx"]
